@@ -607,9 +607,9 @@ class CameraDeviceCapability(str, Enum):
     Battery = "Battery"
 
     PTZ = "PTZ"
+    PTZZoom = "PTZZoom"
     PTZHome = "PTZHome"
     PTZPresets = "PTZPresets"
-    PTZZoom = "PTZZoom"
 
     Snapshot = "Snapshot"
     StreamUrl = "StreamUrl"
@@ -1358,5 +1358,3 @@ class StorageController(Protocol[S]):
     ) -> S: ...
     def get_camera_storage(self, camera_id: str) -> Optional[S]: ...
     def get_plugin_storage(self) -> Optional[S]: ...
-    async def remove_camera_storage(self, camera_id: str) -> None: ...
-    async def remove_plugin_storage(self) -> None: ...
